@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 24.08.2018: Removed unused variables.
 # 06.08.2017: Added audit trail.
 # 08.02.2017: First version.
 
@@ -41,9 +42,6 @@
 addOrder <- function(data, kit=NULL, overwrite=FALSE, ignore.case=FALSE,
                      debug=FALSE){
   
-  # Parameters that are changed by the function must be saved first.
-  attr_data <- substitute(data)
-  
   if(debug){
     print(paste("IN:", match.call()[[1]]))
   }
