@@ -6,6 +6,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 06.08.2017: Added audit trail.
 # 30.09.2016: Fixed a sample name mathcing bug (now really works as check subsetting in gui).
 # 29.08.2014: Added check for uniqueness between reference datasets.
 # 28.08.2014: Fixed bug in drop-out of minor in If 3: AA:AB | (A-B)/(A+B). 
@@ -61,7 +62,7 @@
 #' @references
 #' Bright, Jo-Anne, Jnana Turkington, and John Buckleton.
 #' "Examination of the Variability in Mixed DNA Profile Parameters for the
-#'  IdentifilerTM Multiplex."
+#'  Identifiler Multiplex."
 #'  Forensic Science International: Genetics 4, no. 2 (February 2010): 111-14.
 #'  doi:10.1016/j.fsigen.2009.07.002.
 #' \url{http://dx.doi.org/10.1016/j.fsigen.2009.07.002}
@@ -492,6 +493,9 @@ calculateMixture <- function(data, ref1, ref2, ol.rm=TRUE,
                     Profile=resProfile,
                     Dropin=resDropin,
                     stringsAsFactors=FALSE)
+  
+  # Update audit trail.
+  res <- auditTrail(obj = res, f.call = match.call(), package = "strvalidator")
 
   if(debug){
     print(paste("EXIT:", match.call()[[1]]))
