@@ -4,6 +4,11 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 07.08.2017: Added audit trail.
+# 13.07.2017: Fixed issue with button handlers.
+# 13.07.2017: Fixed narrow dropdown with hidden argument ellipsize = "none".
+# 07.07.2017: Replaced 'droplist' with 'gcombobox'.
+# 07.07.2017: Removed argument 'border' for 'gbutton'.
 # 28.04.2016: 'Save as' textbox expandable.
 # 26.10.2015: Added attributes.
 # 28.08.2015: Added importFrom.
@@ -19,12 +24,6 @@
 # 17.07.2013: 'false' allele checkboxes replaced by gdf table.
 # 17.07.2013: Added check subsetting.
 # 11.06.2013: Fixed wrong interference passed to 'calculateStutter' (-1).
-# 11.06.2013: 'val_replace' and 'val_by' set to NULL if length = 0.
-# 04.06.2013: Fixed bug in 'missingCol'.
-# 30.05.2013: Added replace 'false' stutters.
-# 29.05.2013: Added subset check.
-# 28.05.2013: Added warning for additive effects.
-# 24.05.2013: Improved error message for missing columns.
 
 #' @title Calculate Stutter
 #'
@@ -35,7 +34,7 @@
 #' Simplifies the use of the \code{\link{calculateStutter}} function by providing 
 #' a graphical user interface to it.
 #' 
-#' @param env environment in wich to search for data frames and save result.
+#' @param env environment in which to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
@@ -54,6 +53,8 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   # Global variables.
   .gData <- NULL
   .gRef <- NULL
+  .gDataName <- NULL
+  .gRefName <- NULL
   
   if(debug){
     print(paste("IN:", match.call()[[1]]))
@@ -111,12 +112,13 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   f0g0[1,1] <- glabel(text="Select dataset:", container=f0g0)
   
-  f0g0[1,2] <- f0_dataset_drp <- gdroplist(items=c("<Select dataset>",
+  f0g0[1,2] <- f0_dataset_drp <- gcombobox(items=c("<Select dataset>",
                                               listObjects(env=env,
                                                           obj.class="data.frame")), 
                                       selected = 1,
                                       editable = FALSE,
-                                      container = f0g0)
+                                      container = f0g0,
+                                      ellipsize = "none")
   
   f0g0[1,3] <- f0_samples_lbl <- glabel(text=" 0 samples", container=f0g0)
   
@@ -133,6 +135,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
       
       # Load or change components.
       .gData <<- get(val_obj, envir=env)
+      .gDataName <<- val_obj
       samples <- length(unique(.gData$Sample.Name))
       svalue(f0_samples_lbl) <- paste("", samples, "samples")
       svalue(f2_save_edt) <- paste(val_obj, "_stutter", sep="")
@@ -145,6 +148,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
 
       # Reset components.
       .gData <<- NULL
+      .gDataName <<- NULL
       svalue(f0_dataset_drp, index=TRUE) <- 1
       svalue(f0_samples_lbl) <- " 0 samples"
       svalue(f2_save_edt) <- ""
@@ -155,12 +159,13 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   f0g0[2,1] <- glabel(text="Select reference dataset:", container=f0g0)
   
-  f0g0[2,2] <- f0_refset_drp <- gdroplist(items=c("<Select dataset>",
+  f0g0[2,2] <- f0_refset_drp <- gcombobox(items=c("<Select dataset>",
                                              listObjects(env=env,
                                                          obj.class="data.frame")), 
                                      selected = 1,
                                      editable = FALSE,
-                                     container = f0g0) 
+                                     container = f0g0,
+                                     ellipsize = "none") 
   
   f0g0[2,3] <- f0_ref_lbl <- glabel(text=" 0 references", container=f0g0)
   
@@ -177,6 +182,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
       
       # Load or change components.
       .gRef <<- get(val_obj, envir=env)
+      .gRefName <<- val_obj
       refs <- length(unique(.gRef$Sample.Name))
       svalue(f0_ref_lbl) <- paste("", refs, "references")
         
@@ -184,6 +190,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
       
       # Reset components.
       .gRef <<- NULL
+      .gRefName <<- NULL
       svalue(f0_refset_drp, index=TRUE) <- 1
       svalue(f0_ref_lbl) <- " 0 references"
       
@@ -197,9 +204,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
     print("CHECK")
   }  
   
-  f0g0[3,2] <- f0_check_btn <- gbutton(text="Check subsetting",
-                                  border=TRUE,
-                                  container=f0g0)
+  f0g0[3,2] <- f0_check_btn <- gbutton(text="Check subsetting", container=f0g0)
   
   addHandlerChanged(f0_check_btn, handler = function(h, ...) {
     
@@ -227,7 +232,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
       
     } else {
       
-      gmessage(message="Data frame is NULL!\n\n
+      gmessage(msg="Data frame is NULL!\n\n
                Make sure to select a dataset and a reference set",
                title="Error",
                icon = "error")      
@@ -314,8 +319,8 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   glabel(text=" Kit attribute:", container=f2)
   
-  f2_kit_drp <- gdroplist(items=getKit(), selected = 1,
-                          editable = FALSE, container = f2) 
+  f2_kit_drp <- gcombobox(items=getKit(), selected = 1,
+                          editable = FALSE, container = f2, ellipsize = "none") 
   
 
   # BUTTON ####################################################################
@@ -324,11 +329,9 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
     print("BUTTON")
   }  
   
-  calculate_btn <- gbutton(text="Calculate",
-                      border=TRUE,
-                      container=gv)
+  calculate_btn <- gbutton(text="Calculate", container=gv)
   
-  addHandlerChanged(calculate_btn, handler = function(h, ...) {
+  addHandlerClicked(calculate_btn, handler = function(h, ...) {
     
     # Get values.
     val_back <- svalue(f1g1_range_b_spb)
@@ -336,6 +339,8 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
     val_interference <- svalue(interference_opt, index=TRUE) - 1 # NB! range [0-2]
     val_data <- .gData
     val_ref <- .gRef
+    val_name_data <- .gDataName
+    val_name_ref <- .gRefName
     val_name <- svalue(f2_save_edt)
     val_replace_df <- f3_default_gdf[]
     val_chk <- val_replace_df$Replace
@@ -373,7 +378,9 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
       }
       
       # Change button.
+      blockHandlers(calculate_btn)
       svalue(calculate_btn) <- "Processing..."
+      unblockHandlers(calculate_btn)
       enabled(calculate_btn) <- FALSE
       
       # Calculate stutter.
@@ -384,15 +391,20 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
                                   by.val=val_by,
                                   debug=debug)
       
-      # Add attributes.
+      # Add attributes to result.
       attr(datanew, which="kit") <- val_kit
-      attr(datanew, which="calculateStutter_gui, data") <- svalue(f0_dataset_drp)
-      attr(datanew, which="calculateStutter_gui, ref") <- svalue(f0_refset_drp)
-      attr(datanew, which="calculateStutter_gui, back") <- val_back
-      attr(datanew, which="calculateStutter_gui, forward") <- val_forward
-      attr(datanew, which="calculateStutter_gui, interference") <- val_interference
-      attr(datanew, which="calculateStutter_gui, replace.val") <- val_replace
-      attr(datanew, which="calculateStutter_gui, by.val") <- val_by
+      
+      # Create key-value pairs to log.
+      keys <- list("data", "ref", "back", "forward",
+                   "interference", "replace.val", "by.val")
+      
+      values <- list(val_name_data, val_name_ref, val_back, val_forward,
+                     val_interference, val_replace, val_by)
+      
+      # Update audit trail.
+      datanew <- auditTrail(obj = datanew, key = keys, value = values,
+                            label = "calculateStutter_gui", arguments = FALSE,
+                            package = "strvalidator")
 
       # Save data.
       saveObject(name=val_name, object=datanew, parent=w, env=env)
