@@ -4,6 +4,8 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.07.2018: Fixed error replacing NA's.
+# 10.07.2018: Fixed blank drop-down menues after selecting a dataset.
 # 07.08.2017: Added audit trail.
 # 13.07.2017: Fixed issue with button handlers.
 # 13.07.2017: Fixed narrow drop-down with hidden argument ellipsize = "none".
@@ -441,7 +443,7 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=N
         if(val_task == 1){  # crop
           .gData <<- .gData[!is.na(.gData[[val_column]]), ]
         } else {  # replace
-          .gData[val_column][is.na(.gData[[val_column]])] <<- val_new
+          .gData[val_column][is.na(.gData[val_column])] <<- val_new
         }
         
       } else if (val_operator == 8){  # is not NA
@@ -449,7 +451,7 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=N
         if(val_task == 1){  # crop
           .gData <<- .gData[is.na(.gData[[val_column]]), ]
         } else {  # replace
-          .gData[val_column][!is.na(.gData[[val_column]])] <<- val_new
+          .gData[val_column][!is.na(.gData[val_column])] <<- val_new
         }
         
       } else if (val_operator == 9){  # containing
@@ -580,6 +582,9 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=N
       # Populate drop list.
       f1_column_drp[] <- c("<Select column>", dfs)
       
+      # Select default value.
+      svalue(f1_column_drp, index=TRUE) <- 1
+
       unblockHandler(f1_column_drp)
       
     }
@@ -655,6 +660,10 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=N
       if(length(selectedColumn)!=0){
         if(selectedColumn %in% names(.gData)){
           f2g1_target_cbo[,] <- unique(.gData[selectedColumn])
+          
+          # Select default value.
+          svalue(f2g1_target_cbo, index=TRUE) <- 1
+          
         }
       }
     }
