@@ -4,6 +4,11 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 18.07.2017: Fixed "Warning: Ignoring unknown aesthetics: ymax".
+# 13.07.2017: Fixed issue with button handlers.
+# 13.07.2017: Fixed narrow dropdown with hidden argument ellipsize = "none".
+# 07.07.2017: Replaced 'droplist' with 'gcombobox'.
+# 07.07.2017: Removed argument 'border' for 'gbutton'.
 # 29.04.2016: 'Save as' textbox expandable.
 # 11.11.2015: Added importFrom ggplot2.
 # 29.08.2015: Added importFrom.
@@ -18,13 +23,13 @@
 #' @description
 #' GUI simplifying the creation of plots from result type data.
 #'
-#' @details Plot result type data. It is possible to customise titles and font
+#' @details Plot result type data. It is possible to customize titles and font
 #' size. Data can be plotted as as frequency or proportion. The values can be
 #' printed on the plot with custom number of decimals. There are several 
-#' colour palettes to chose from. 
-#' A name for the result is automatiaclly suggested.
+#' color palettes to chose from. 
+#' A name for the result is automatically suggested.
 #' The resulting plot can be saved as either a plot object or as an image.
-#' @param env environment in wich to search for data frames and save result.
+#' @param env environment in which to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
@@ -103,12 +108,13 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   glabel(text="Select dataset:", container=f0)
 
-  dataset_drp <- gdroplist(items=c("<Select dataset>",
+  dataset_drp <- gcombobox(items=c("<Select dataset>",
                                    listObjects(env=env,
                                                obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
-                           container = f0) 
+                           container = f0,
+                           ellipsize = "none") 
   
   f0_samples_lbl <- glabel(text=" (0 samples)", container=f0)
 
@@ -194,11 +200,12 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   grid2[1,2] <- f1_base_size_edt <- gedit(text="18", width=4, container=grid2)
   
   grid3 <- glayout(container = f1, spacing = 1)
-  grid3[1,1] <- glabel(text="Colour palette:", container=grid3)
-  grid3[1,2] <- f1_palette_drp <- gdroplist(items=.palette,
+  grid3[1,1] <- glabel(text="Color palette:", container=grid3)
+  grid3[1,2] <- f1_palette_drp <- gcombobox(items=.palette,
                                             selected = 1,
                                             editable = FALSE,
-                                            container = grid3)
+                                            container = grid3,
+                                            ellipsize = "none")
 
   grid4 <- glayout(container = f1, spacing = 1)
   grid4[1,1] <- f1_print_chk <- gcheckbox(text="Print values as bar labels", checked=TRUE, container=grid4)
@@ -210,7 +217,7 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   # FRAME 7 ###################################################################
   
-  plot_btn <- gbutton(text="Plot", border=TRUE, container=gv) 
+  plot_btn <- gbutton(text="Plot", container=gv) 
   
   addHandlerChanged(plot_btn, handler = function(h, ...) {
     
@@ -232,20 +239,18 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   f5_save_edt <- gedit(text="", container=f5, expand = TRUE)
   
-  f5_save_btn <- gbutton(text = "Save as object",
-                         border=TRUE,
-                         container = f5) 
+  f5_save_btn <- gbutton(text = "Save as object", container = f5) 
 
-  f5_ggsave_btn <- gbutton(text = "Save as image",
-                         border=TRUE,
-                         container = f5) 
+  f5_ggsave_btn <- gbutton(text = "Save as image", container = f5) 
   
-  addHandlerChanged(f5_save_btn, handler = function(h, ...) {
+  addHandlerClicked(f5_save_btn, handler = function(h, ...) {
     
     val_name <- svalue(f5_save_edt)
 
     # Change button.
+    blockHandlers(f5_save_btn)
     svalue(f5_save_btn) <- "Processing..."
+    unblockHandlers(f5_save_btn)
     enabled(f5_save_btn) <- FALSE
     
     # Save data.
@@ -253,7 +258,9 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
                parent=w, env=env, debug=debug)
     
     # Change button.
+    blockHandlers(f5_save_btn)
     svalue(f5_save_btn) <- "Object saved"
+    unblockHandlers(f5_save_btn)
     
   } )
 
@@ -358,8 +365,7 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
       
       # Print value labels on bars.
       if(val_print){
-        gp <- gp + geom_text(aes_string(x="Group", y="freq",
-                                 ymax="freq", label="lab", 
+        gp <- gp + geom_text(aes_string(x="Group", y="freq", label="lab",
                                  hjust=0.5, vjust=0), size=val_lab_size)
       }
 
@@ -378,7 +384,7 @@ plotPeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
         
     } else {
       
-      gmessage(message="Data frame is NULL or NA!",
+      gmessage(msg="Data frame is NULL or NA!",
                title="Error",
                icon = "error")      
       
