@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 24.08.2018: Removed unused variables.
 # 07.08.2017: Added audit trail.
 # 28.04.2016: First version.
 
@@ -38,10 +39,6 @@
 
 removeSpike <- function(data, spike, invert=FALSE, debug=FALSE){
   
-  # Parameters that are changed by the function must be saved first.
-  attr_data <- substitute(data)
-  attr_spike <- substitute(spike)
-
   if(debug){
     print(paste("IN:", match.call()[[1]]))
     print("data:")
