@@ -4,6 +4,11 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 07.08.2017: Added audit trail.
+# 13.07.2017: Fixed issue with button handlers.
+# 13.07.2017: Fixed narrow dropdown with hidden argument ellipsize = "none".
+# 07.07.2017: Replaced 'droplist' with 'gcombobox'.
+# 07.07.2017: Removed argument 'border' for 'gbutton'.
 # 16.06.2016: 'Save as' textbox expandable.
 # 29.08.2015: Added importFrom.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
@@ -22,7 +27,7 @@
 #' Simplifies the use of the \code{\link{tableCapillary}} function by providing a graphical 
 #' user interface to it.
 #' 
-#' @param env environment in wich to search for data frames.
+#' @param env environment in which to search for data frames.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
@@ -95,12 +100,13 @@ tableCapillary_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
   
   f0g0[1,1] <- glabel(text="Select dataset:", container=f0g0)
   
-  f0g0[1,2] <- f0g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
+  f0g0[1,2] <- f0g0_dataset_drp <- gcombobox(items=c("<Select dataset>",
                                                      listObjects(env=env,
                                                                  obj.class="data.frame")),
                                              selected = 1,
                                              editable = FALSE,
-                                             container = f0g0)
+                                             container = f0g0,
+                                             ellipsize = "none")
   
   f0g0[1,3] <- f0g0_samples_lbl <- glabel(text=" 0 rows",
                                               container=f0g0)
@@ -182,14 +188,13 @@ tableCapillary_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
     print("BUTTON")
   }  
   
-  run_btn <- gbutton(text="Make table",
-                      border=TRUE,
-                      container=gv)
+  run_btn <- gbutton(text="Make table", container=gv)
   
-  addHandlerChanged(run_btn, handler = function(h, ...) {
+  addHandlerClicked(run_btn, handler = function(h, ...) {
     
     # Get values.
     val_data <- .gData
+    val_name_data <- .gDataName
     val_scope <- svalue(f1g1_scope_opt)
     val_name <- svalue(f2_save_edt)
 
@@ -209,13 +214,25 @@ tableCapillary_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
     if (!is.null(.gData)){
       
       # Change button.
+      blockHandlers(run_btn)
       svalue(run_btn) <- "Processing..."
+      unblockHandlers(run_btn)
       enabled(run_btn) <- FALSE
       
       datanew <- tableCapillary(data=val_data,
                                 scope=val_scope,
                                 debug=debug)
       
+      # Create key-value pairs to log.
+      keys <- list("data", "scope")
+      
+      values <- list(val_name_data, val_scope)
+      
+      # Update audit trail.
+      datanew <- auditTrail(obj = datanew, key = keys, value = values,
+                            label = "tableCapillary_gui", arguments = FALSE,
+                            package = "strvalidator")
+      
       # Save data.
       saveObject(name=val_name, object=datanew, parent=w, env=env)
       
@@ -229,7 +246,7 @@ tableCapillary_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, pa
       
     } else {
       
-      gmessage(message="Data frame is NULL!\n\n
+      gmessage(msg="Data frame is NULL!\n\n
                Make sure to select a dataset and a reference set",
                title="Error",
                icon = "error")      
